#!/usr/bin/env python3
"""
Volute-PPT package main entry point.
Allows running: python -m volute_ppt.server_local
"""

import sys
from .server_local import main

if __name__ == "__main__":
    main()
